@@ -1,7 +1,7 @@
 #! /usr/bin/env python
 
 """
-ver 2010 09 03 12
+ver 2010 09 08 10
 autor Bartlomiej Ceglik
 e-mail yoyoek[no spam]wp.pl
 """
@@ -146,20 +146,18 @@ def Sql_insert_correct(s_con, s_id, s_into, s_values, s_vars ):
     q = 'insert into '+s_into+' ('+list_join(s_values,',')+') VALUES ('+vars_tmp+')'
 
     if sql_debug:
-        print "[q] [%s]\n[q][ insert values ]  [%s]" %(q, vars_tmp)
+        print "[q] [%s]\n[q] [ insert values ]  [%s]" %(q, vars_tmp)
 
     try:
         count = s_vars[0][0]
+        #print "[q] insert get s_var as list!"
         #print "\n-------------\n"+str(s_vars)+"\n-list------------"
         for s in s_vars:
             c.execute(q,s)
     except:
-        if len( s_vars ) == len( s_values ):
-            print "[q] insert get s_var as singiel record"
-            #print "\n-------------\n"+str(s_vars)+"\n-singiel------------"
-            c.execute(q,s_vars)
-        else:
-            print "[q] insert get singiel record - error "
+        #print "[q] insert get s_var as singiel record"
+        #print "\n-------------\n"+str(s_vars)+"\n-singiel------------"
+        c.execute(q,s_vars)
 
     s_con.commit()
 
@@ -253,7 +251,7 @@ def Run_import():
                                             'CalendarId',
                                             'Calendars',
                                             ['Name',        'Colour','IsVisible','IsReadonly',   'CalendarType','CalendarTune',  'CalendarVersion',  'CalendarProfile'],
-                                            [str(cal_name), colour,  '1',         '1',           '0',            '',             '1.0',                '0']
+                                            [str(cal_name), colour,  '1',         '1',           '0',            '',             '1',                '0']
                                             )
                 if cal_id == None:
                     break
@@ -272,28 +270,15 @@ def Run_import():
 
                 location = Call_featch_val(e,'location')
                 desc = Call_featch_val(e, 'description')
-                entryDate = Call_featch_val(e, 'created')
-                if entryDate:
-                    entryDate = ParseStrTime_to_unix(entryDate)
-                    if entryDate < 0:
-                        entryDate = 0
-                modDate = Call_featch_val(e, 'last-modified')
-                if modDate:
-                    modDate = ParseStrTime_to_unix(modDate)
-                    if modDate < 0:
-                        modeDate = 0
-
-                print "entry(%s) mod(%s)" % ( entryDate, modDate )
-
                 ev_ta.append(
-                             [cal_id,        '1',                '-1',   tStart,         tEnd,        e['summary'],      location,           desc,               '-1',       '0',        '-1',   '0',    str(entryDate),     str(modDate),        ':UTC', '0']
+                             [cal_id,        '1',                '-1',   tStart,         tEnd,        e['summary'],      location,           desc,               '-1',       '0',        '-1',   '0',    '0',            '0',            ':UTC', '0']
                              )
 
             print "[Start ical iter]    [db insert %i/%i] [%s]" % (len(ev_ta),count_total, cal_name)
             Sql_insert_correct(s_con,
                         '',
                         'Components',
-                        ['CalendarId',      'ComponentType',    'Flags','DateStart',    'DateEnd',  'Summary',          'Location',         'Description',      'Status',   'Uid',     'Until', 'AllDay','CreatedTime', 'ModifiedTime', 'Tzid','TzOffset'],
+                        ['CalendarId',  'ComponentType',    'Flags','DateStart',    'DateEnd',  'Summary',          'Location',         'Description',      'Status',   'Uid',     'Until','AllDay','CreatedTime', 'ModifiedTime', 'Tzid','TzOffset'],
                         ev_ta
                         )
 
